@@ -31,7 +31,7 @@ class SongScore(Base):
     difficulty: int
     clear_type: int
     best_clear_type: int
-    time_played: int
+    time_played: datetime
     near_count: int
     miss_count: int
     perfect_count: int
