@@ -3,7 +3,6 @@ from nonebot.params import CommandArg
 from ..main import arc
 from ..draw_text import draw_song
 from .._RHelper import RHelper
-from typing import Dict
 from ..AUA.request import get_song_info
 from ..AUA.schema.api.another.song_info_detail import SongInfoDetail
 from ..AUA.schema.utils import diffstr2num
@@ -13,12 +12,17 @@ root = RHelper()
 
 async def song_handler(bot: Bot, event: MessageEvent, args: Message = CommandArg()):
     args: list = str(args).split()
-    args: Dict = {i: v for i, v in enumerate(args)}
-    if args.get(0, None) == "song":
+    """
+        /arc song Fracture Ray ftr
+    """
+    if len(args) >= 2 and args[0] == "song":
         # get args
-        songname = args.get(1, None)
-        difficulty = args.get(2, "ALL")
-        difficulty = diffstr2num(difficulty.upper())
+        if difficulty := diffstr2num(args[-1].upper()):
+            songname = " ".join(args[1:-1])
+        else:
+            difficulty = -1
+            songname = " ".join(args[1:])
+        # query
         resp = await get_song_info(songname, difficulty)
         data = SongInfoDetail(**resp)
         if error_message := data.message:
