@@ -9,6 +9,9 @@ from .handlers import (
     recent_handler,
     b30_handler,
     best_handler,
+    song_handler,
+    random_handler,
+    post_handler,
 )
 
 
@@ -21,3 +24,6 @@ arc.handle()(info_handler)
 arc.handle()(recent_handler)
 arc.handle()(b30_handler)
 arc.handle()(best_handler)
+arc.handle()(song_handler)
+arc.handle()(random_handler)
+arc.handle()(post_handler)
